package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Entry struct {
Timestamp string `json:"timestamp"`
Endpoint string `json:"endpoint"`
URL string `json:"url,omitempty"`
Status string `json:"status"`
Statement string `json:"statement"`
Error string `json:"error,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.