package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Request struct {
Query string `json:"query"`
Variables map[string]any `json:"variables,omitempty"`
}
Execute sends a GraphQL request.
Header priority: config headers < stored credential < extraHeaders (CLI -H flags).
Source Files
¶
Click to show internal directories.
Click to hide internal directories.